# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/cjm-byte-track',
                'doc_host': 'https://cj-mills.github.io',
                'git_url': 'https://github.com/cj-mills/cjm-byte-track',
                'lib_path': 'cjm_byte_track'},
  'syms': { 'cjm_byte_track.basetrack': { 'cjm_byte_track.basetrack.BaseTrack': ('basetrack.html#basetrack', 'cjm_byte_track/basetrack.py'),
                                          'cjm_byte_track.basetrack.BaseTrack.__init__': ( 'basetrack.html#basetrack.__init__',
                                                                                           'cjm_byte_track/basetrack.py'),
                                          'cjm_byte_track.basetrack.BaseTrack.activate': ( 'basetrack.html#basetrack.activate',
                                                                                           'cjm_byte_track/basetrack.py'),
                                          'cjm_byte_track.basetrack.BaseTrack.end_frame': ( 'basetrack.html#basetrack.end_frame',
                                                                                            'cjm_byte_track/basetrack.py'),
                                          'cjm_byte_track.basetrack.BaseTrack.mark_lost': ( 'basetrack.html#basetrack.mark_lost',
                                                                                            'cjm_byte_track/basetrack.py'),
                                          'cjm_byte_track.basetrack.BaseTrack.mark_removed': ( 'basetrack.html#basetrack.mark_removed',
                                                                                               'cjm_byte_track/basetrack.py'),
                                          'cjm_byte_track.basetrack.BaseTrack.next_id': ( 'basetrack.html#basetrack.next_id',
                                                                                          'cjm_byte_track/basetrack.py'),
                                          'cjm_byte_track.basetrack.BaseTrack.predict': ( 'basetrack.html#basetrack.predict',
                                                                                          'cjm_byte_track/basetrack.py'),
                                          'cjm_byte_track.basetrack.BaseTrack.update': ( 'basetrack.html#basetrack.update',
                                                                                         'cjm_byte_track/basetrack.py'),
                                          'cjm_byte_track.basetrack.TrackState': ( 'basetrack.html#trackstate',
                                                                                   'cjm_byte_track/basetrack.py')},
            'cjm_byte_track.byte_tracker': { 'cjm_byte_track.byte_tracker.BYTETracker': ( 'byte_tracker.html#bytetracker',
                                                                                          'cjm_byte_track/byte_tracker.py'),
                                             'cjm_byte_track.byte_tracker.BYTETracker.__init__': ( 'byte_tracker.html#bytetracker.__init__',
                                                                                                   'cjm_byte_track/byte_tracker.py'),
                                             'cjm_byte_track.byte_tracker.BYTETracker._get_detections': ( 'byte_tracker.html#bytetracker._get_detections',
                                                                                                          'cjm_byte_track/byte_tracker.py'),
                                             'cjm_byte_track.byte_tracker.BYTETracker._match_tracks_to_detections': ( 'byte_tracker.html#bytetracker._match_tracks_to_detections',
                                                                                                                      'cjm_byte_track/byte_tracker.py'),
                                             'cjm_byte_track.byte_tracker.BYTETracker._process_output': ( 'byte_tracker.html#bytetracker._process_output',
                                                                                                          'cjm_byte_track/byte_tracker.py'),
                                             'cjm_byte_track.byte_tracker.BYTETracker._scale_bboxes': ( 'byte_tracker.html#bytetracker._scale_bboxes',
                                                                                                        'cjm_byte_track/byte_tracker.py'),
                                             'cjm_byte_track.byte_tracker.BYTETracker._update_tracked_stracks': ( 'byte_tracker.html#bytetracker._update_tracked_stracks',
                                                                                                                  'cjm_byte_track/byte_tracker.py'),
                                             'cjm_byte_track.byte_tracker.BYTETracker._update_tracks': ( 'byte_tracker.html#bytetracker._update_tracks',
                                                                                                         'cjm_byte_track/byte_tracker.py'),
                                             'cjm_byte_track.byte_tracker.BYTETracker.update': ( 'byte_tracker.html#bytetracker.update',
                                                                                                 'cjm_byte_track/byte_tracker.py'),
                                             'cjm_byte_track.byte_tracker.joint_stracks': ( 'byte_tracker.html#joint_stracks',
                                                                                            'cjm_byte_track/byte_tracker.py'),
                                             'cjm_byte_track.byte_tracker.remove_duplicate_stracks': ( 'byte_tracker.html#remove_duplicate_stracks',
                                                                                                       'cjm_byte_track/byte_tracker.py'),
                                             'cjm_byte_track.byte_tracker.sub_stracks': ( 'byte_tracker.html#sub_stracks',
                                                                                          'cjm_byte_track/byte_tracker.py')},
            'cjm_byte_track.core': { 'cjm_byte_track.core.BYTETracker': ('byte_tracker.html#bytetracker', 'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.BYTETracker.__init__': ( 'byte_tracker.html#bytetracker.__init__',
                                                                                   'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.BYTETracker._get_detections': ( 'byte_tracker.html#bytetracker._get_detections',
                                                                                          'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.BYTETracker._match_tracks_to_detections': ( 'byte_tracker.html#bytetracker._match_tracks_to_detections',
                                                                                                      'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.BYTETracker._process_output': ( 'byte_tracker.html#bytetracker._process_output',
                                                                                          'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.BYTETracker._scale_bboxes': ( 'byte_tracker.html#bytetracker._scale_bboxes',
                                                                                        'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.BYTETracker._update_tracked_stracks': ( 'byte_tracker.html#bytetracker._update_tracked_stracks',
                                                                                                  'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.BYTETracker._update_tracks': ( 'byte_tracker.html#bytetracker._update_tracks',
                                                                                         'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.BYTETracker.update': ( 'byte_tracker.html#bytetracker.update',
                                                                                 'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.STrack': ('byte_tracker.html#strack', 'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.STrack.__init__': ('byte_tracker.html#strack.__init__', 'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.STrack.__repr__': ('byte_tracker.html#strack.__repr__', 'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.STrack._update_track': ( 'byte_tracker.html#strack._update_track',
                                                                                   'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.STrack.activate': ('byte_tracker.html#strack.activate', 'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.STrack.multi_predict': ( 'byte_tracker.html#strack.multi_predict',
                                                                                   'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.STrack.predict': ('byte_tracker.html#strack.predict', 'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.STrack.re_activate': ( 'byte_tracker.html#strack.re_activate',
                                                                                 'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.STrack.tlbr': ('byte_tracker.html#strack.tlbr', 'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.STrack.tlbr_to_tlwh': ( 'byte_tracker.html#strack.tlbr_to_tlwh',
                                                                                  'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.STrack.tlwh': ('byte_tracker.html#strack.tlwh', 'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.STrack.tlwh_to_tlbr': ( 'byte_tracker.html#strack.tlwh_to_tlbr',
                                                                                  'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.STrack.tlwh_to_xyah': ( 'byte_tracker.html#strack.tlwh_to_xyah',
                                                                                  'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.STrack.update': ('byte_tracker.html#strack.update', 'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.joint_stracks': ('byte_tracker.html#joint_stracks', 'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.remove_duplicate_stracks': ( 'byte_tracker.html#remove_duplicate_stracks',
                                                                                       'cjm_byte_track/core.py'),
                                     'cjm_byte_track.core.sub_stracks': ('byte_tracker.html#sub_stracks', 'cjm_byte_track/core.py')},
            'cjm_byte_track.kalman_filter': { 'cjm_byte_track.kalman_filter.KalmanFilter': ( 'kalman_filter.html#kalmanfilter',
                                                                                             'cjm_byte_track/kalman_filter.py'),
                                              'cjm_byte_track.kalman_filter.KalmanFilter.__init__': ( 'kalman_filter.html#kalmanfilter.__init__',
                                                                                                      'cjm_byte_track/kalman_filter.py'),
                                              'cjm_byte_track.kalman_filter.KalmanFilter._create_std': ( 'kalman_filter.html#kalmanfilter._create_std',
                                                                                                         'cjm_byte_track/kalman_filter.py'),
                                              'cjm_byte_track.kalman_filter.KalmanFilter.gating_distance': ( 'kalman_filter.html#kalmanfilter.gating_distance',
                                                                                                             'cjm_byte_track/kalman_filter.py'),
                                              'cjm_byte_track.kalman_filter.KalmanFilter.initiate': ( 'kalman_filter.html#kalmanfilter.initiate',
                                                                                                      'cjm_byte_track/kalman_filter.py'),
                                              'cjm_byte_track.kalman_filter.KalmanFilter.multi_predict': ( 'kalman_filter.html#kalmanfilter.multi_predict',
                                                                                                           'cjm_byte_track/kalman_filter.py'),
                                              'cjm_byte_track.kalman_filter.KalmanFilter.predict': ( 'kalman_filter.html#kalmanfilter.predict',
                                                                                                     'cjm_byte_track/kalman_filter.py'),
                                              'cjm_byte_track.kalman_filter.KalmanFilter.project': ( 'kalman_filter.html#kalmanfilter.project',
                                                                                                     'cjm_byte_track/kalman_filter.py'),
                                              'cjm_byte_track.kalman_filter.KalmanFilter.update': ( 'kalman_filter.html#kalmanfilter.update',
                                                                                                    'cjm_byte_track/kalman_filter.py')},
            'cjm_byte_track.matching': { 'cjm_byte_track.matching.box_iou_batch': ( 'matching.html#box_iou_batch',
                                                                                    'cjm_byte_track/matching.py'),
                                         'cjm_byte_track.matching.indices_to_matches': ( 'matching.html#indices_to_matches',
                                                                                         'cjm_byte_track/matching.py'),
                                         'cjm_byte_track.matching.iou_distance': ( 'matching.html#iou_distance',
                                                                                   'cjm_byte_track/matching.py'),
                                         'cjm_byte_track.matching.ious': ('matching.html#ious', 'cjm_byte_track/matching.py'),
                                         'cjm_byte_track.matching.linear_assignment': ( 'matching.html#linear_assignment',
                                                                                        'cjm_byte_track/matching.py'),
                                         'cjm_byte_track.matching.match_detections_with_tracks': ( 'matching.html#match_detections_with_tracks',
                                                                                                   'cjm_byte_track/matching.py')},
            'cjm_byte_track.strack': { 'cjm_byte_track.strack.STrack': ('strack.html#strack', 'cjm_byte_track/strack.py'),
                                       'cjm_byte_track.strack.STrack.__init__': ('strack.html#strack.__init__', 'cjm_byte_track/strack.py'),
                                       'cjm_byte_track.strack.STrack.__repr__': ('strack.html#strack.__repr__', 'cjm_byte_track/strack.py'),
                                       'cjm_byte_track.strack.STrack._update_track': ( 'strack.html#strack._update_track',
                                                                                       'cjm_byte_track/strack.py'),
                                       'cjm_byte_track.strack.STrack.activate': ('strack.html#strack.activate', 'cjm_byte_track/strack.py'),
                                       'cjm_byte_track.strack.STrack.multi_predict': ( 'strack.html#strack.multi_predict',
                                                                                       'cjm_byte_track/strack.py'),
                                       'cjm_byte_track.strack.STrack.predict': ('strack.html#strack.predict', 'cjm_byte_track/strack.py'),
                                       'cjm_byte_track.strack.STrack.re_activate': ( 'strack.html#strack.re_activate',
                                                                                     'cjm_byte_track/strack.py'),
                                       'cjm_byte_track.strack.STrack.tlbr': ('strack.html#strack.tlbr', 'cjm_byte_track/strack.py'),
                                       'cjm_byte_track.strack.STrack.tlbr_to_tlwh': ( 'strack.html#strack.tlbr_to_tlwh',
                                                                                      'cjm_byte_track/strack.py'),
                                       'cjm_byte_track.strack.STrack.tlwh': ('strack.html#strack.tlwh', 'cjm_byte_track/strack.py'),
                                       'cjm_byte_track.strack.STrack.tlwh_to_tlbr': ( 'strack.html#strack.tlwh_to_tlbr',
                                                                                      'cjm_byte_track/strack.py'),
                                       'cjm_byte_track.strack.STrack.tlwh_to_xyah': ( 'strack.html#strack.tlwh_to_xyah',
                                                                                      'cjm_byte_track/strack.py'),
                                       'cjm_byte_track.strack.STrack.update': ('strack.html#strack.update', 'cjm_byte_track/strack.py')}}}
